from django import template
from django.template.defaultfilters import stringfilter
from django.utils import formats
from django.utils.safestring import mark_safe

register = template.Library()


@register.filter
def value(val, pm=False):
    if not val:
        return mark_safe("&ndash;")
    _prefix = ""
    _suffix = "&nbsp;€"
    _val = formats.number_format(val, 2, use_l10n=True, force_grouping=True)

    if val > 0:
        if pm:
            _prefix += "&plus;&nbsp;"
    else:
        _val = _val[1:]
        _prefix += "&minus;&nbsp;"

    return mark_safe(f"{_prefix}{_val}{_suffix}")


@register.filter
def pmvalue(val):
    return value(val, True)


@register.inclusion_tag("main/tag/transaction_table.html")
def transaction_table(transactions):
    return {"transactions": transactions}


@register.inclusion_tag("main/tag/form_buttons.html")
def form_buttons(instance):
    return {
        "instance": instance,
        "adding": instance._state.adding,
        "del_url": f"del_{instance.__class__.__name__.lower()}",
    }
